# pyperclip-stubs

[![QA](https://github.com/Tatsh/pyperclip-stubs/actions/workflows/qa.yml/badge.svg)](https://github.com/Tatsh/pyperclip-stubs/actions/workflows/qa.yml)
[![PyPI - Version](https://img.shields.io/pypi/v/pyperclip-stubs)](https://pypi.org/project/pyperclip-stubs/)
![GitHub tag (with filter)](https://img.shields.io/github/v/tag/Tatsh/pyperclip-stubs)
![GitHub](https://img.shields.io/github/license/Tatsh/pyperclip-stubs)
![GitHub commits since latest release (by SemVer including pre-releases)](https://img.shields.io/github/commits-since/Tatsh/pyperclip-stubs/v0.0.2/master)

Stubs for `pyperclip`.

## Installation

```shell
pip install pyperclip-stubs
```
